"use strict";(self.webpackChunk_bitwarden_web_vault=self.webpackChunk_bitwarden_web_vault||[]).push([[712],{21712:(n,t,o)=>{o.d(t,{OrganizationVaultExportComponent:()=>g});var r=o(5076),e=o(86573),i=o(72932),a=o(25065),u=o(33812),s=o(23649),d=o(26657),c=o(56898),p=o(10672),l=o(93748),f=o(88016),b=function(n,t,o,r){return new(o||(o=Promise))(function(e,i){function a(n){try{s(r.next(n))}catch(t){i(t)}}function u(n){try{s(r.throw(n))}catch(t){i(t)}}function s(n){var t;n.done?e(n.value):(t=n.value,t instanceof o?t:new o(function(n){n(t)})).then(a,u)}s((r=r.apply(n,t||[])).next())})};class g{constructor(n){this.route=n,this.routeOrgId=void 0,this.loading=!1,this.disabled=!1}ngOnInit(){return b(this,void 0,void 0,function*(){const n=this.route.snapshot.paramMap.get("organizationId");if(void 0===n)throw new Error("`organizationId` is a required route parameter");if(!(0,r.e)(n))throw new Error("Invalid OrganizationId provided in route parameter `organizationId`");this.routeOrgId=n})}onSuccessfulExport(n){return b(this,void 0,void 0,function*(){})}}g.ɵfac=function(n){return new(n||g)(u.rXU(s.nX))},g.ɵcmp=u.VBU({type:g,selectors:[["ng-component"]],decls:6,vars:7,consts:[[3,"formDisabled","formLoading","onSuccessfulExport","organizationId"],["form","export_form_exportForm","bitButton","","type","submit","bitFormButton","","buttonType","primary",3,"disabled","loading"]],template:function(n,t){1&n&&(u.nrm(0,"app-header"),u.j41(1,"bit-container")(2,"tools-export",0),u.bIt("formDisabled",function(n){return t.disabled=n})("formLoading",function(n){return t.loading=n})("onSuccessfulExport",function(n){return t.onSuccessfulExport(n)}),u.k0s(),u.j41(3,"button",1),u.EFF(4),u.nI1(5,"i18n"),u.k0s()()),2&n&&(u.R7$(2),u.Y8G("organizationId",u.mNQ(t.routeOrgId)),u.R7$(),u.Y8G("disabled",t.disabled)("loading",t.loading),u.R7$(),u.SpI(" ",u.bMT(5,5,"export")," "))},dependencies:[a.G,d.$,c.Q,p.H,e.i,i.G,l.f,f.$],encapsulation:2})}}]);
//# sourceMappingURL=712.36ecc57259a750067d7a.js.map