"use strict";(self.webpackChunk_bitwarden_web_vault=self.webpackChunk_bitwarden_web_vault||[]).push([[677],{47677:(n,t,o)=>{o.d(t,{ExportWebComponent:()=>b});var e=o(86573),r=o(72932),i=o(25065),u=o(33812),s=o(23649),c=o(26657),a=o(56898),d=o(10672),l=o(93748),f=o(88016),p=function(n,t,o,e){return new(o||(o=Promise))(function(r,i){function u(n){try{c(e.next(n))}catch(t){i(t)}}function s(n){try{c(e.throw(n))}catch(t){i(t)}}function c(n){var t;n.done?r(n.value):(t=n.value,t instanceof o?t:new o(function(n){n(t)})).then(u,s)}c((e=e.apply(n,t||[])).next())})};class b{constructor(n){this.router=n,this.loading=!1,this.disabled=!1}onSuccessfulExport(n){return p(this,void 0,void 0,function*(){})}}b.ɵfac=function(n){return new(n||b)(u.rXU(s.Ix))},b.ɵcmp=u.VBU({type:b,selectors:[["ng-component"]],decls:6,vars:5,consts:[[3,"formDisabled","formLoading","onSuccessfulExport"],["form","export_form_exportForm","bitButton","","type","submit","bitFormButton","","buttonType","primary",3,"disabled","loading"]],template:function(n,t){1&n&&(u.nrm(0,"app-header"),u.j41(1,"bit-container")(2,"tools-export",0),u.bIt("formDisabled",function(n){return t.disabled=n})("formLoading",function(n){return t.loading=n})("onSuccessfulExport",function(n){return t.onSuccessfulExport(n)}),u.k0s(),u.j41(3,"button",1),u.EFF(4),u.nI1(5,"i18n"),u.k0s()()),2&n&&(u.R7$(3),u.Y8G("disabled",t.disabled)("loading",t.loading),u.R7$(),u.SpI(" ",u.bMT(5,3,"export")," "))},dependencies:[i.G,c.$,a.Q,d.H,e.i,r.G,l.f,f.$],encapsulation:2})}}]);
//# sourceMappingURL=677.98a0060cb9547db54359.js.map